import { AuthOptions } from "next-auth";
import CredentialsProvider from "next-auth/providers/credentials";

import { BaseUrl } from "@/configs/api";
import { env } from "@/env/server";

export const authOptions: AuthOptions = {
	pages: {
		signIn: "/ar/login",
		signOut: "/ar/logout",
		error: "/ar/error",
	},
	providers: [
		CredentialsProvider({
			name: "Credentials",
			credentials: {
				email: { label: "Email", type: "text" },
				password: { label: "Password", type: "password" },
			},
			async authorize(credentials) {
				const res = await fetch(`${BaseUrl}/login`, {
					method: "POST",
					body: JSON.stringify({
						email: credentials?.email,
						password: credentials?.password,
					}),
					headers: { "Content-Type": "application/json" },
				});

				const user = await res.json();

				if (res.ok && user) {
					return {
						id: user.Data.user.id,
						sub: user.Data.user.id,
						email: user.Data.user.email,
						last_name: user.Data.user.last_name,
						first_name: user.Data.user.first_name,
						token: user.Data.token,
						name: `${user.Data.user.first_name} ${user.Data.user.last_name}`,
					};
				}

				return null;
			},
		}),
	],
	callbacks: {
		async jwt({ token, user }) {
			if (user) {
				token.id = user.id as number;
				token.sub = user.id as number;
				token.email = user.email;
				token.first_name = user.first_name;
				token.last_name = user.last_name;
				token.exp = token.exp;
				token.iat = token.iat;
				token.jti = token.jti;
				token.name = user.name;
				token.token = user.token;
			}

			return token;
		},
		async session({ session, token: all_data }) {
			const { token, ...other } = all_data;

			session.user = other;

			return session;
		},
	},
	jwt: {
		secret: "suleiman",
		maxAge: 10 * 24 * 60 * 60,
		// secret: env.JWT_SECRET,
		// maxAge: parseInt(env.JWT_MAX_AGE),
	},
	cookies: {
		sessionToken: {
			name: "next-auth.session-token",
			options: {
				httpOnly: true,
				sameSite: "lax",
				path: "/",
				secure: env.NODE_ENV === "production",
			},
		},
	},
	session: { strategy: "jwt" },
	logger: {
		error(code, metadata) {
			console.error(code, metadata);
		},
		warn(code) {
			console.warn(code);
		},
		debug(code, metadata) {
			console.log(code, metadata);
		},
	},
	events: {
		session: async (message) => {
			console.log("session", message);
		},
	},
};
